@@ -34,13 +34,15 @@ static R_CallMethodDef CallEntries[] = {
     {"pBunchKaufman_validate", (DL_FUNC) &pBunchKaufman_validate, 1},
     {"Cholesky_validate", (DL_FUNC) &Cholesky_validate, 1},
     {"Csparse_Csparse_prod", (DL_FUNC) &Csparse_Csparse_prod, 2},
-    {"Csparse_dense_prod", (DL_FUNC) &Csparse_dense_prod, 2},
-    {"Csparse_dense_crossprod", (DL_FUNC) &Csparse_dense_crossprod, 2},
     {"Csparse_crossprod", (DL_FUNC) &Csparse_crossprod, 3},
-    {"Csparse_to_dense", (DL_FUNC) &Csparse_to_dense, 1},
+    {"Csparse_dense_crossprod", (DL_FUNC) &Csparse_dense_crossprod, 2},
+    {"Csparse_dense_prod", (DL_FUNC) &Csparse_dense_prod, 2},
+    {"Csparse_horzcat", (DL_FUNC) &Csparse_horzcat, 2},
     {"Csparse_to_Tsparse", (DL_FUNC) &Csparse_to_Tsparse, 1},
+    {"Csparse_to_dense", (DL_FUNC) &Csparse_to_dense, 1},
     {"Csparse_transpose", (DL_FUNC) &Csparse_transpose, 1},
     {"Csparse_validate", (DL_FUNC) &Csparse_validate, 1},
+    {"Csparse_vertcat", (DL_FUNC) &Csparse_vertcat, 2},
     {"pCholesky_validate", (DL_FUNC) &pCholesky_validate, 1},
     {"graphNEL_as_dgTMatrix", (DL_FUNC) &graphNEL_as_dgTMatrix, 2},
     {"LU_expand", (DL_FUNC) &LU_expand, 1},
